#!/bin/bash

###############################################################################
#
# SPDX-License-Identifier: MIT
#
# Run ansible-playbook within docker
#   ./docker-playbook.sh [parameters]
#
# For example:
# - Run a playbook:
#   ./docker-playbook -i hosts stacks/kvm-host.yml -K
# - Force rebuild the docker image
#   ./docker-playbook rebuild
#
###############################################################################

# shellcheck disable=SC2154
# shellcheck disable=SC2086

CURR_DIR=$(readlink -f "$(dirname "$0")")

check_user_in_docker() {
    if [[ $(groups "$USER") != *"docker"* ]]; then
        echo "Please add the current user $USER into docker group."
        exit 1
    fi
}

check_docker_cmd() {
    if ! command -v docker &> /dev/null; then
        echo "Please install docker first."
        exit 1
    fi
}

build_docker_image() {
    echo "Build ansible-playbook container image..."
    docker build \
        --build-arg http_proxy="$http_proxy" \
        --build-arg https_proxy="$https_proxy" \
        --build-arg no_proxy="$no_proxy" \
        "$@" \
        -t ansible-playbook \
        .
}

run_docker() {
    MAP_HOSTS_FILE=""
    if [[ -f /etc/ansible/hosts ]]; then
        echo "NOTE: Found the file /etc/ansible/hosts, will be mapped into docker."
        MAP_HOSTS_FILE="-v /etc/ansible/hosts:/etc/ansible/hosts"
    fi
    
    MAP_CONFIG_FILE=""
    if [[ -f /etc/ansible/ansible.cfg ]]; then
        echo "NOTE: Found the file /etc/ansible/ansible.cfg, will be mapped into docker."
        MAP_CONFIG_FILE="-v /etc/ansible/ansible.cfg:/etc/ansible/ansible.cfg"
    fi

    docker run \
        -e http_proxy -e https_proxy -e no_proxy \
        -v ~/.ssh/:/home/sgxdev/host_ssh:ro \
        -v "${CURR_DIR}":/home/sgxdev/deployment \
        ${MAP_HOSTS_FILE} \
        ${MAP_CONFIG_FILE} \
        -it \
        ansible-playbook "$@"
}

check_docker_cmd
check_user_in_docker

# if only want to build the docker image ansible-playbook
if [[ $1 == "rebuild" ]]; then
    build_docker_image --no-cache --force-rm
    exit
fi

# if the docker image has not been build at first time, build it
[ -n "$(docker images -q ansible-playbook)" ] || build_docker_image

# Run ansible-playbook within docker
run_docker "$@"
